@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.55 2002/10/28 08:33:30 bazsi Exp $
+ * $Id: affile.c,v 1.56 2002/10/30 19:28:11 bazsi Exp $
  *
  ***************************************************************************/
  
@@ -507,41 +507,47 @@ struct macro_def {
 #define M_MIN      10
 #define M_SEC      11
 #define M_WEEKDAY  12
-#define M_UNIXTIME 13
+#define M_TZOFFSET 13
+#define M_TZ       14
+#define M_UNIXTIME 15
 
-#define M_DATE_RECVD     14
-#define M_FULLDATE_RECVD 15
-#define M_ISODATE_RECVD  16
-#define M_YEAR_RECVD     17
-#define M_MONTH_RECVD    18
-#define M_DAY_RECVD      19
-#define M_HOUR_RECVD     20
-#define M_MIN_RECVD      21
-#define M_SEC_RECVD      22
-#define M_WEEKDAY_RECVD  23
-#define M_UNIXTIME_RECVD 24
+#define M_DATE_RECVD     16
+#define M_FULLDATE_RECVD 17
+#define M_ISODATE_RECVD  18
+#define M_YEAR_RECVD     19
+#define M_MONTH_RECVD    20
+#define M_DAY_RECVD      21
+#define M_HOUR_RECVD     22
+#define M_MIN_RECVD      23
+#define M_SEC_RECVD      24
+#define M_WEEKDAY_RECVD  25
+#define M_TZOFFSET_RECVD 26
+#define M_TZ_RECVD       27
+#define M_UNIXTIME_RECVD 28
 
-#define M_DATE_STAMP     25
-#define M_FULLDATE_STAMP 26
-#define M_ISODATE_STAMP  27
-#define M_YEAR_STAMP     28
-#define M_MONTH_STAMP    29
-#define M_DAY_STAMP      30
-#define M_HOUR_STAMP     31
-#define M_MIN_STAMP      32
-#define M_SEC_STAMP      33
-#define M_WEEKDAY_STAMP  34
-#define M_UNIXTIME_STAMP 35
+#define M_DATE_STAMP     30
+#define M_FULLDATE_STAMP 31
+#define M_ISODATE_STAMP  32
+#define M_YEAR_STAMP     33
+#define M_MONTH_STAMP    34
+#define M_DAY_STAMP      35
+#define M_HOUR_STAMP     36
+#define M_MIN_STAMP      37
+#define M_SEC_STAMP      38
+#define M_WEEKDAY_STAMP  39
+#define M_TZOFFSET_STAMP 40
+#define M_TZ_STAMP       41
+#define M_UNIXTIME_STAMP 42
 
-#define M_FULLHOST 36
-#define M_HOST     37
-#define M_FULLHOST_FROM 38
-#define M_HOST_FROM  39
-#define M_PROGRAM  40
+#define M_FULLHOST       43
+#define M_HOST           44
+#define M_FULLHOST_FROM  45
+#define M_HOST_FROM      46
+#define M_PROGRAM        47
 
-#define M_MESSAGE  41
+#define M_MESSAGE        48
 
-#define M_SOURCE_IP 42
+#define M_SOURCE_IP      49
 
 int append_string(char **dest, int *left, char *str, int length, int escape)
 {
@@ -666,6 +672,8 @@ void expand_macro(struct syslog_config *cfg, int id, int escape, char **dest, un
 	case M_HOUR_RECVD:
 	case M_MIN_RECVD:
 	case M_SEC_RECVD:
+	case M_TZOFFSET_RECVD:
+	case M_TZ_RECVD:
 	case M_UNIXTIME_RECVD:
 
 	case M_FULLDATE_STAMP:
@@ -678,6 +686,8 @@ void expand_macro(struct syslog_config *cfg, int id, int escape, char **dest, un
 	case M_HOUR_STAMP:
 	case M_MIN_STAMP:
 	case M_SEC_STAMP:
+	case M_TZOFFSET_STAMP:
+	case M_TZ_STAMP:
 	case M_UNIXTIME_STAMP:
 
 	case M_FULLDATE:
@@ -690,6 +700,8 @@ void expand_macro(struct syslog_config *cfg, int id, int escape, char **dest, un
 	case M_HOUR:
 	case M_MIN:
 	case M_SEC:
+	case M_TZOFFSET:
+	case M_TZ:
 	case M_UNIXTIME: {
 		/* year, month, day */
 		struct tm *tm;
@@ -706,6 +718,8 @@ void expand_macro(struct syslog_config *cfg, int id, int escape, char **dest, un
 	       	case M_HOUR_RECVD:    
 	       	case M_MIN_RECVD:     
 	       	case M_SEC_RECVD:     
+		case M_TZOFFSET_RECVD:
+		case M_TZ_RECVD:
 	       	case M_UNIXTIME_RECVD:     
 			unixtime = msg->recvd;
 			break;
@@ -719,6 +733,8 @@ void expand_macro(struct syslog_config *cfg, int id, int escape, char **dest, un
 		case M_HOUR_STAMP:    
 		case M_MIN_STAMP:     
 		case M_SEC_STAMP:     
+		case M_TZOFFSET_STAMP:
+		case M_TZ_STAMP:
 		case M_UNIXTIME_STAMP:     
 			unixtime = msg->stamp;
 	                break;
@@ -783,6 +799,16 @@ void expand_macro(struct syslog_config *cfg, int id, int escape, char **dest, un
  	        case M_DATE_STAMP:
 	                length = strftime(*dest, *left - 1, "%h %e %H:%M:%S", tm);
 	                break;
+	        case M_TZOFFSET:
+ 	        case M_TZOFFSET_RECVD:
+ 	        case M_TZOFFSET_STAMP:
+			length = strftime(*dest, *left -1, "%z", tm);
+			break;
+	        case M_TZ:
+ 	        case M_TZ_RECVD:
+ 	        case M_TZ_STAMP:
+			length = strftime(*dest, *left -1, "%Z", tm);
+			break;
 	        case M_UNIXTIME:
  	        case M_UNIXTIME_RECVD:
  	        case M_UNIXTIME_STAMP:
@@ -826,6 +852,8 @@ expand_macros(struct syslog_config *cfg, struct ol_string *template, int templat
 		{ "SEC", M_SEC },
 		{ "WEEKDAY", M_WEEKDAY },
 		{ "UNIXTIME", M_UNIXTIME },
+		{ "TZOFFSET", M_TZOFFSET },
+		{ "TZ", M_TZ },
 
  		{ "R_DATE", M_DATE_RECVD },
  		{ "R_FULLDATE", M_FULLDATE_RECVD },
@@ -838,6 +866,8 @@ expand_macros(struct syslog_config *cfg, struct ol_string *template, int templat
  		{ "R_SEC", M_SEC_RECVD },
  		{ "R_WEEKDAY", M_WEEKDAY_RECVD },
 		{ "R_UNIXTIME", M_UNIXTIME_RECVD },
+		{ "R_TZOFFSET", M_TZOFFSET_RECVD },
+		{ "R_TZ", M_TZ_RECVD },
  
  		{ "S_DATE", M_DATE_STAMP },
  		{ "S_FULLDATE", M_FULLDATE_STAMP },
@@ -850,6 +880,8 @@ expand_macros(struct syslog_config *cfg, struct ol_string *template, int templat
  		{ "S_SEC", M_SEC_STAMP },
  		{ "S_WEEKDAY", M_WEEKDAY_STAMP },
  		{ "S_UNIXTIME", M_UNIXTIME_STAMP },
+ 		{ "S_TZOFFSET", M_TZOFFSET_STAMP },
+ 		{ "S_TZ", M_TZ_STAMP },
 		
 		{ "HOST_FROM", M_HOST_FROM },
 		{ "FULLHOST_FROM", M_FULLHOST_FROM },
