@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.h,v 1.18 2002/03/19 09:26:16 bazsi Exp $
+ * $Id: affile.h,v 1.19 2002/07/18 13:18:01 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -63,7 +63,7 @@ void affile_set_file_template(struct log_dest_driver *c, char *template);
 void affile_set_template_escape(struct log_dest_driver *c, int enable);
 void affile_set_remove_if_older(struct log_dest_driver *c, int interval);
 
-struct log_source_driver *make_affile_source(const char *name, int flags, UINT8 *prefix);
+struct log_source_driver *make_affile_source(const char *name, int flags, UINT8 *prefix, UINT32 pad_size);
 struct log_dest_driver *make_affile_dest(const char *name, int flags);
 
 #endif
