@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: cfgfile.h,v 1.24 2002/08/21 14:03:50 bazsi Exp $
+ * $Id: cfgfile.h,v 1.25 2002/10/18 12:31:08 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -52,7 +52,7 @@
 	(stats_freq simple UINT32)
 	(time_reopen simple UINT32)
 	(time_reap simple UINT32)
-	(log_fifo_size simple UINT32)
+	(log_fifo_size simple int)
 	(use_time_recvd simple UINT32)
 	(use_fqdn simple UINT32)
 	(use_dns simple UINT32)
