@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: log.h,v 1.17 2002/04/26 09:43:54 bazsi Exp $
+ * $Id: log.h,v 1.18 2002/08/21 14:03:50 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -56,6 +56,9 @@ struct log_info {
 #define LF_INTERNAL           0x0001
 #define LF_MARK               0x0002
 #define LF_LOCAL              0x0004
+#define LF_CHECK_HOSTNAME     0x0100
+
+#define LF_USER_FLAGS 0xff00
 
 /* CLASS:
      (class
@@ -86,7 +89,7 @@ struct log_info {
 struct log_info *log_info_use(struct log_info *msg);
 void log_info_free(struct log_info *msg);
 
-struct log_info *make_log_info(UINT32 length, UINT8 *data, UINT8 *prefix);
+struct log_info *make_log_info(UINT32 length, UINT8 *data, UINT8 *prefix, UINT32 flags);
 struct log_info *make_internal_message(UINT32 pri, UINT32 length, UINT8 *data);
 struct log_info *make_mark_message(void);
 
