@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: main.c,v 1.46 2002/10/14 08:24:05 bazsi Exp $
+ * $Id: main.c,v 1.48 2002/10/30 19:36:03 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -41,6 +41,11 @@
 #include <getopt.h>
 #include <grp.h>
 #include <pwd.h>
+
+#if HAVE_ARPA_NAMESER_H
+#include <arpa/nameser.h>
+#endif
+
 #include <resolv.h>
 
 #include "main.c.x"
@@ -493,16 +498,29 @@ int main(int argc, char **argv)
 		return 2;
 	}
 	if (chroot_dir) {
-		if (chroot(chroot_dir) < 0) {
+		if (chdir(chroot_dir) < 0) {
+			werror("Error chdiring, exiting.\n");
+			return 3;
+		}
+		if (chroot(".") < 0) {
 			werror("Error chrooting, exiting.\n");
 			return 3;
 		}
 	}
 	
 	if (uid || gid) {
-		setgid(gid);
-		setgroups(0, NULL);
-		setuid(uid);
+		if (gid && setgid(gid) < 0) {
+			werror("Error in setgid(), exiting.\n");
+			return 4;
+		}
+		if (setgroups(0, NULL) < 0) {
+			werror("Error in setgroups(), exiting.\n");
+			return 4;
+		}
+		if (uid && setuid(uid) < 0) {
+			werror("Error setuid(), exiting.\n");
+			return 4;
+		}
 	}
 
 	if (!debug_flag) {
