@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: sources.c,v 1.35 2002/08/21 14:03:50 bazsi Exp $
+ * $Id: sources.c,v 1.36 2002/10/28 08:33:30 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -163,10 +163,10 @@ make_log_reader(UINT32 dgram,
 	self->dgram = dgram;
 	self->next = next;
 	self->prefix = prefix;
-	self->max_log_line = MAX(max_log_line, pad_size) + 1;
+	self->max_log_line = MAX(max_log_line, pad_size);
 	self->pad_size = pad_size;
 	self->msg_flags = msg_flags;
-	self->buffer = ol_space_alloc(max_log_line);
+	self->buffer = ol_space_alloc(self->max_log_line);
 	
 	return &self->super;
 }
